summaryrefslogtreecommitdiffstats
path: root/src/repository/mod.rs
diff options
context:
space:
mode:
authorMatthias Beyer <mail@beyermatthias.de>2018-10-21 14:25:25 +0200
committerMatthias Beyer <mail@beyermatthias.de>2018-10-21 14:54:29 +0200
commit2b6e3fb20f8069a1853873467a4c864997343603 (patch)
treef8e4eb7076eb4c6ba21989bc6b2bae5c16d02ee7 /src/repository/mod.rs
parentb87da505fae69294fbcb8efe405cfaa30d03ac6b (diff)
Implement publishing
Diffstat (limited to 'src/repository/mod.rs')
-rw-r--r--src/repository/mod.rs8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/repository/mod.rs b/src/repository/mod.rs
index fa782c9..84937ce 100644
--- a/src/repository/mod.rs
+++ b/src/repository/mod.rs
@@ -196,14 +196,14 @@ impl Repository {
"10m"
}
/// Announce a profile as current
///
/// Profile identified by IPFS hash.
///
/// Lifetime and TTL are _not_ set to the default in the implementation of this function, but
/// the IPFS defaults apply (set by the IPFS daemon)
///
- pub fn announce_profile<'a>(&'a self,
+ pub fn announce_block<'a>(&'a self,
key: ProfileKey,
state: &IPFSHash,
lifetime: Option<String>,
@@ -212,7 +212,7 @@ impl Repository {
{
debug!("Announcing profile: key: {key:?}, state: {state:?}, lifetime: {lifetime:?}, ttl: {ttl:?}",
key = key, state = state, lifetime = lifetime, ttl = ttl);
- ::repository::client::announce_profile(self.client.clone(), key, state, lifetime, ttl)
+ ::repository::client::announce_block(self.client.clone(), key, state, lifetime, ttl)
}
pub fn new_profile<'a>(&'a self,
@@ -196,14 +196,14 @@ impl Repository {
"10m"
}
- /// Announce a profile as current
+ /// Announce a block as current
///
@@ -196,14 +196,14 @@ impl Repository {
///
- /// Profile identified by IPFS hash.
+ /// Block identified by IPFS hash.
///
/// Lifetime and TTL are _not_ set to the default in the implementation of this function, but